@@ -233,11 +233,19 @@ function showExampleMap() {
 
 function divideVerticalSpaceEqually() {
     /* For #evenly-spaced-vertical, divide the vertical space evenly between
-    the .vertical-item elements.  Take note of the 4px border between them.
+    the .vertical-item elements.  Take note of the 4px border between
+    them.
+    Note that a "not-evenly-spaced" element will be given half the
+    space.
+    Handy for forms underneath the graphs.
     */
-    var numberOfItems = $('#evenly-spaced-vertical > .vertical-item').length;
-    verticalItemHeight = Math.floor(mainContentHeight / numberOfItems) - 1;
+    var numberOfItems, numberOfDoubleItems;
+    numberOfItems = $('#evenly-spaced-vertical > .vertical-item').length;
+    numberOfDoubleItems = $('#evenly-spaced-vertical > .double-vertical-item').length;
+    verticalItemHeight = Math.floor(
+        (mainContentHeight / (numberOfItems + 2 * numberOfDoubleItems))) - 1;
     $('#evenly-spaced-vertical > .vertical-item').height(verticalItemHeight);
+    $('#evenly-spaced-vertical > .double-vertical-item').height(2 * verticalItemHeight);
 }
 
 
